<?php

namespace Drupal\responsive_voice_tts\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\node\Entity\NodeType;

/**
 * Provides a configuration form for the ResponsiveVoice TTS module.
 */
class ResponsiveVoiceTtsConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   *
   * This method gets the form ID for this config form.
   *
   * @return string
   *   The unique form ID.
   */
  public function getFormId() {
    return 'responsive_voice_tts_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['responsive_voice_tts.settings'];
  }

  /**
   * {@inheritdoc}
   *
   * Builds the form elements for configuration.
   *
   * @param array $form
   *   An associative array containing the form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('responsive_voice_tts.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('if you dont have API, you can create one using this link https://app.responsivevoice.org/'),
    ];
    // Get all content types.
    $content_types = NodeType::loadMultiple();

    // Checkbox options for content types.
    $options = [];
    foreach ($content_types as $content_type) {
      $options[$content_type->id()] = $content_type->label();
    }

    // Add form elements for selecting content types and position.
    $form['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select content types to enable TTS'),
      '#options' => $options,
      '#default_value' => $config->get('content_types') ?? [],
    ];

    $form['text_for_play_button'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Audio Play Button Text'),
      '#default_value' => $config->get('text_for_play_button') ?? $this->t('Prefer listening? Hear this article now!'),
      '#description' => $this->t('This text will appear alongside the speaker icon to prompt users to listen to the post. It will be displayed on top or bottom of the selected content types.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   *
   * Submit the form elements for configuration.
   *
   * @param array $form
   *   An associative array containing the form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('responsive_voice_tts.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('content_types', array_filter($form_state->getValue('content_types')))
      ->set('text_for_play_button', $form_state->getValue('text_for_play_button'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
