<?php

namespace Drupal\responsive_voice_tts\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\node\NodeInterface;
use Drupal\responsive_voice_tts\SpeakerService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'ResponsiveVoiceBlock' block.
 *
 * @Block(
 *   id = "responsive_voice_block",
 *   admin_label = @Translation("Responsive Voice Block"),
 * )
 */
class ResponsiveVoiceTtsBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The current user service.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The speaker service for TTS functionality.
   *
   * @var \Drupal\responsive_voice_tts\SpeakerService
   */
  protected $speakerService;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccountProxyInterface $currentUser, EntityTypeManagerInterface $entityTypeManager, SpeakerService $speaker_service) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $currentUser;
    $this->entityTypeManager = $entityTypeManager;
    $this->speakerService = $speaker_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user'),
      $container->get('entity_type.manager'),
      $container->get('responsive_voice_tts.speaker_service')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $node = \Drupal::routeMatch()->getParameter('node');
    if ($node instanceof NodeInterface) {
      $body = $node->get('body')->value;
      $output = $this->speakerService->generateSpeechOutput(addslashes(strip_tags($body)));
      $build['content'] = $output;
      return $build;
    }
    return [];
  }

}
