<?php

namespace Drupal\responsive_voice_tts;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;

/**
 * Class SpeakerService.
 *
 * Provides text-to-speech functionality using the ResponsiveVoice API.
 */
class SpeakerService {

  use StringTranslationTrait;

  /**
   * The configuration factory service.
   *
   * This is used to retrieve the module's configuration settings.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Generate text-to-speech HTML output.
   *
   * @param string $text
   *   The text to be spoken.
   * @param string $voice
   *   The selected voice (e.g., male or female).
   *
   * @return string
   *   HTML with the play button.
   */
  public function generateSpeechOutput($text, $voice = 'UK English Female') {

    $config = $this->configFactory->get('responsive_voice_tts.settings');
    if (empty($config->get('api_key'))) {
      return [
        '#markup' => $this->t('Please configure the API key and other settings on the <a href=":config_link">module configuration page</a>.', [
          ':config_link' => Url::fromRoute('responsive_voice_tts.config_form')->toString(),
        ]),
      ];
    }

    $render_array = [
      '#theme' => 'speech_output_template',
      '#text' => $text,
      '#voice' => $voice,
      '#button_text' => $config->get('text_for_play_button'),
      '#attached' => [
        'html_head' => [
        [
          [
            '#tag' => 'script',
            '#attributes' => [
              'src' => 'https://code.responsivevoice.org/responsivevoice.js?key=' . $config->get('api_key'),
              'type' => 'application/javascript',
            ],
          ],
          'responsivevoice_external_js',
        ],
        ],
        // Attach the library separately from html_head.
        'library' => ['responsive_voice_tts/responsivevoice'],
      ],
    ];

    return $render_array;
  }

}
